import { WebView } from 'react-native-webview';
import React from 'react'

interface Props {
  onVisible: boolean,
  authToken: string,
  widgetId: string,
  identifier?: string,
  extraProps?: any,
  onCompletion(data : any): void
}

/**
 *
 * @param {boolean} onVisible - onVisible prop to manage the visibility of the widget
 * @param {string} authToken - authToken provided by MSG91
 * @param {string} widgetId - widgetId provided by MSG91
 * @param {string} identifier - (OPTIONAL) unique value mobile number or email address.
 * @param {object} extraProps - (OPTIONAL) object with unique keys and values, template variables.
 * @returns {object} - onCompletion Callback that is called when the widget receives any response. Response object is passed as an argument to the callback handler.
 */

const OTPVerification: React.FC<Props> = ({
  onVisible,
  authToken,
  widgetId,
  identifier='',
  extraProps,
  onCompletion
}) => {
  let replaceContent = "";
  for (var k in extraProps) {
    if (extraProps.hasOwnProperty(k)) {
      replaceContent += `${k}: "${extraProps[k]}", `;
    }
  }
  function onMessage(data) {
    onCompletion(data.nativeEvent.data)
  }
  var verificationScript = `
  <html>
  <head>
     
  </head>
  <body onload="initOTPWidget()">
  <script type="text/javascript">
  var configuration = {
  widgetId: ":widgetId",
  tokenAuth: ":authToken",
  identifier: ":identifier",
  success: (data) => {
  sendDataToReactNativeApp(data);
  },
  failure: (error) => {
  sendDataToReactNativeApp(error);
  },
  :replaceContent
  };
  </script>
  <script type="text/javascript" src="https://control.msg91.com/app/assets/otp-provider/otp-provider.js"> </script>
  <script>
  function initOTPWidget() {
  initSendOTP(configuration);
  }
  function sendDataToReactNativeApp(data) {
  window.ReactNativeWebView.postMessage(JSON.stringify(data));
  };
  </script>
  </body>
  </html>`.replace(':widgetId',widgetId).replace(':authToken',authToken).replace(':identifier',identifier).replace(':replaceContent',replaceContent)

  if(onVisible){
    return (
      <WebView
        containerStyle={{position:'absolute', height: '100%', width: '100%' }}
        onMessage={onMessage}
        source={{ 
          html: verificationScript,
          baseUrl: "https://control.msg91.com/app/assets/otp-provider/otp-provider.js"
         }} />
    )
  }else{
    return null;
  }
   
}

export default OTPVerification